@@ -122,17 +122,16 @@ static const char *aa_vbgr_xpm[] = {
 #define DEFAULT_ICON_THEME "hicolor"
 #define INITIAL_ICON_THEME "Rodent"
 #define DEFAULT_TOOLBAR_STYLE "icons"
-#define DEFAULT_FONT "Sans 10"
+#define DEFAULT_FONT "Sans 9"
 #define DEFAULT_XFT_ANTIALIAS 1
-#define DEFAULT_XFT_HINTING 0
-#define DEFAULT_XFT_HINTSTYLE "hintnone"
+#define DEFAULT_XFT_HINTING 1
+#define DEFAULT_XFT_HINTSTYLE "hintfull"
 #define DEFAULT_XFT_RGBA "none"
 
 #define MAX_ELEMENTS_BEFORE_SCROLLING 6
 
 static gboolean setting_model = FALSE;
 static gboolean setting_itheme_model = FALSE;
-static gboolean initial_scroll = TRUE;
 static gboolean is_running = FALSE;
 static gchar *current_theme = NULL;
 static gchar *current_icon_theme = NULL;
@@ -285,13 +284,16 @@ static void read_themes(Itf * dialog)
     GList *list;
     GtkTreeModel *model;
     GtkTreeView *tree_view;
+    GtkTreePath *path;
+    GtkTreeIter iter;
+    GtkTreeIter iter_found;
     gint i = 0;
     gboolean current_theme_found = FALSE;
-    GtkTreeRowReference *row_ref = NULL;
+
 
     gtk_theme_list = theme_common_get_list(gtk_theme_list);
     tree_view = GTK_TREE_VIEW(dialog->theme_treeview);
-    model = gtk_tree_view_get_model(tree_view);
+    model = gtk_tree_view_get_model(GTK_TREE_VIEW (tree_view));
 
     setting_model = TRUE;
     gtk_list_store_clear(GTK_LIST_STORE(model));
@@ -302,7 +304,6 @@ static void read_themes(Itf * dialog)
     for(list = gtk_theme_list; list; list = list->next)
     {
         ThemeInfo *info = list->data;
-        GtkTreeIter iter;
 
         if(!info->has_gtk)
             continue;
@@ -312,10 +313,8 @@ static void read_themes(Itf * dialog)
 
         if(strcmp(current_theme, info->name) == 0)
         {
-            GtkTreePath *path = gtk_tree_model_get_path(model, &iter);
-            row_ref = gtk_tree_row_reference_new(model, path);
-            gtk_tree_path_free(path);
             current_theme_found = TRUE;
+            iter_found = iter;
         }
 
         if(i == MAX_ELEMENTS_BEFORE_SCROLLING)
@@ -330,32 +329,17 @@ static void read_themes(Itf * dialog)
 
     if(!current_theme_found)
     {
-        GtkTreeIter iter;
-        GtkTreePath *path;
-
         gtk_list_store_prepend(GTK_LIST_STORE(model), &iter);
         gtk_list_store_set(GTK_LIST_STORE(model), &iter, THEME_NAME_COLUMN, DEFAULT_THEME, -1);
-
-        path = gtk_tree_model_get_path(model, &iter);
-        row_ref = gtk_tree_row_reference_new(model, path);
-        gtk_tree_path_free(path);
+        iter_found = iter;
     }
 
-    if(row_ref)
+    path = gtk_tree_model_get_path(model, &iter_found);
+    if (path)
     {
-        GtkTreePath *path;
-
-        path = gtk_tree_row_reference_get_path(row_ref);
-        gtk_tree_view_set_cursor(tree_view, path, NULL, FALSE);
-
-        if(initial_scroll)
-        {
-            gtk_tree_view_scroll_to_cell(tree_view, path, NULL, TRUE, 0.5, 0.0);
-            initial_scroll = FALSE;
-        }
-
+        gtk_tree_view_set_cursor(GTK_TREE_VIEW (tree_view), path, NULL, FALSE);
+        gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW (tree_view), path, NULL, TRUE, 0.5, 0.0);
         gtk_tree_path_free(path);
-        gtk_tree_row_reference_free(row_ref);
     }
     setting_model = FALSE;
 }
@@ -366,9 +350,11 @@ static void read_icon_themes(Itf * dialog)
     gchar **icon_theme_dirs;
     GtkTreeModel *model;
     GtkTreeView *tree_view;
+    GtkTreePath *path;
+    GtkTreeIter iter;
+    GtkTreeIter iter_found;
     gint i, j = 0;
     gboolean current_theme_found = FALSE;
-    GtkTreeRowReference *row_ref = NULL;
     GDir *dir;
     const gchar *file;
 
@@ -436,10 +422,8 @@ static void read_icon_themes(Itf * dialog)
 
             if(strcmp(current_icon_theme, file) == 0)
             {
-                GtkTreePath *path = gtk_tree_model_get_path(model, &iter);
-                row_ref = gtk_tree_row_reference_new(model, path);
-                gtk_tree_path_free(path);
                 current_theme_found = TRUE;
+                iter_found = iter;
             }
 
             if(j == MAX_ELEMENTS_BEFORE_SCROLLING)
@@ -459,32 +443,17 @@ static void read_icon_themes(Itf * dialog)
 
     if(!current_theme_found)
     {
-        GtkTreeIter iter;
-        GtkTreePath *path;
-
         gtk_list_store_prepend(GTK_LIST_STORE(model), &iter);
         gtk_list_store_set(GTK_LIST_STORE(model), &iter, THEME_NAME_COLUMN, DEFAULT_ICON_THEME, THEME_NAME_COLUMN + 1, DEFAULT_ICON_THEME, -1);
-
-        path = gtk_tree_model_get_path(model, &iter);
-        row_ref = gtk_tree_row_reference_new(model, path);
-        gtk_tree_path_free(path);
+        iter_found = iter;
     }
 
-    if(row_ref)
+    path = gtk_tree_model_get_path(model, &iter_found);
+    if (path)
     {
-        GtkTreePath *path;
-
-        path = gtk_tree_row_reference_get_path(row_ref);
-        gtk_tree_view_set_cursor(tree_view, path, NULL, FALSE);
-
-        if(initial_scroll)
-        {
-            gtk_tree_view_scroll_to_cell(tree_view, path, NULL, TRUE, 0.5, 0.0);
-            initial_scroll = FALSE;
-        }
-
+        gtk_tree_view_set_cursor(GTK_TREE_VIEW (tree_view), path, NULL, FALSE);
+        gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW (tree_view), path, NULL, TRUE, 0.5, 0.0);
         gtk_tree_path_free(path);
-        gtk_tree_row_reference_free(row_ref);
     }
     setting_itheme_model = FALSE;
 }
@@ -1157,7 +1126,7 @@ static void setup_dialog(Itf * itf)
     g_signal_connect(G_OBJECT(itf->aa_item23), "activate", G_CALLBACK(on_rgba_vrgb_activate), itf);
     g_signal_connect(G_OBJECT(itf->aa_item24), "activate", G_CALLBACK(on_rgba_vbgr_activate), itf);
 
-    gtk_window_set_position(GTK_WINDOW(itf->theme_dialog), GTK_WIN_POS_CENTER);
+    xfce_gtk_window_center_on_monitor_with_pointer (GTK_WINDOW (itf->theme_dialog));
     gtk_widget_show(itf->theme_dialog);
 }
 
@@ -1236,7 +1205,7 @@ static void create_channel(McsPlugin * mcs_plugin)
             g_free(current_icon_theme);
         }
 
-        current_icon_theme = g_strdup(DEFAULT_ICON_THEME);
+        current_icon_theme = g_strdup(INITIAL_ICON_THEME);
         mcs_manager_set_string(mcs_plugin->manager, "Net/IconThemeName", CHANNEL, current_icon_theme);
     }
 
